# Django CMS QE

Django CMS Quick & Easy provides all important modules to run new page
without a lot of coding. Aims to do it very easily and securely.

For more information please read [documentation](<https://websites.pages.labs.nic.cz/django-cms-qe>).

## Development

To prepare your dev envrionment run this command:

    make prepare-dev

To run tests or lint use this commands:

    make test
    make lint

To run example use this command:

    make run-example

To find more useful commands, run just `make`.
